@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.apigateway_v1.services.api_gateway_service import pagers
@@ -184,17 +186,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_gateways(
         self,
-        request: apigateway.ListGatewaysRequest = None,
+        request: Union[apigateway.ListGatewaysRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGatewaysAsyncPager:
         r"""Lists Gateways in a given project and location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.ListGatewaysRequest`):
+            request (Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListGateways
             parent (:class:`str`):
@@ -264,17 +266,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_gateway(
         self,
-        request: apigateway.GetGatewayRequest = None,
+        request: Union[apigateway.GetGatewayRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Gateway:
         r"""Gets details of a single Gateway.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.GetGatewayRequest`):
+            request (Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetGateway
             name (:class:`str`):
@@ -339,12 +341,12 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_gateway(
         self,
-        request: apigateway.CreateGatewayRequest = None,
+        request: Union[apigateway.CreateGatewayRequest, dict] = None,
         *,
         parent: str = None,
         gateway: apigateway.Gateway = None,
         gateway_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -352,7 +354,7 @@ class ApiGatewayServiceAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.CreateGatewayRequest`):
+            request (Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateGateway
             parent (:class:`str`):
@@ -451,18 +453,18 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_gateway(
         self,
-        request: apigateway.UpdateGatewayRequest = None,
+        request: Union[apigateway.UpdateGatewayRequest, dict] = None,
         *,
         gateway: apigateway.Gateway = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Gateway.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.UpdateGatewayRequest`):
+            request (Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateGateway
             gateway (:class:`google.cloud.apigateway_v1.types.Gateway`):
@@ -557,17 +559,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_gateway(
         self,
-        request: apigateway.DeleteGatewayRequest = None,
+        request: Union[apigateway.DeleteGatewayRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Gateway.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.DeleteGatewayRequest`):
+            request (Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteGateway
             name (:class:`str`):
@@ -658,17 +660,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_apis(
         self,
-        request: apigateway.ListApisRequest = None,
+        request: Union[apigateway.ListApisRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApisAsyncPager:
         r"""Lists Apis in a given project and location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.ListApisRequest`):
+            request (Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListApis
             parent (:class:`str`):
@@ -738,17 +740,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_api(
         self,
-        request: apigateway.GetApiRequest = None,
+        request: Union[apigateway.GetApiRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Api:
         r"""Gets details of a single Api.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.GetApiRequest`):
+            request (Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetApi
             name (:class:`str`):
@@ -809,19 +811,19 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_api(
         self,
-        request: apigateway.CreateApiRequest = None,
+        request: Union[apigateway.CreateApiRequest, dict] = None,
         *,
         parent: str = None,
         api: apigateway.Api = None,
         api_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Api in a given project and location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.CreateApiRequest`):
+            request (Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateApi
             parent (:class:`str`):
@@ -919,18 +921,18 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_api(
         self,
-        request: apigateway.UpdateApiRequest = None,
+        request: Union[apigateway.UpdateApiRequest, dict] = None,
         *,
         api: apigateway.Api = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Api.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.UpdateApiRequest`):
+            request (Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApi
             api (:class:`google.cloud.apigateway_v1.types.Api`):
@@ -1022,17 +1024,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_api(
         self,
-        request: apigateway.DeleteApiRequest = None,
+        request: Union[apigateway.DeleteApiRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Api.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.DeleteApiRequest`):
+            request (Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApi
             name (:class:`str`):
@@ -1123,17 +1125,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_api_configs(
         self,
-        request: apigateway.ListApiConfigsRequest = None,
+        request: Union[apigateway.ListApiConfigsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApiConfigsAsyncPager:
         r"""Lists ApiConfigs in a given project and location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.ListApiConfigsRequest`):
+            request (Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListApiConfigs
             parent (:class:`str`):
@@ -1203,17 +1205,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_api_config(
         self,
-        request: apigateway.GetApiConfigRequest = None,
+        request: Union[apigateway.GetApiConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.ApiConfig:
         r"""Gets details of a single ApiConfig.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.GetApiConfigRequest`):
+            request (Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetApiConfig
             name (:class:`str`):
@@ -1275,12 +1277,12 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_api_config(
         self,
-        request: apigateway.CreateApiConfigRequest = None,
+        request: Union[apigateway.CreateApiConfigRequest, dict] = None,
         *,
         parent: str = None,
         api_config: apigateway.ApiConfig = None,
         api_config_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -1288,7 +1290,7 @@ class ApiGatewayServiceAsyncClient:
         location.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.CreateApiConfigRequest`):
+            request (Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateApiConfig
             parent (:class:`str`):
@@ -1385,18 +1387,18 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_api_config(
         self,
-        request: apigateway.UpdateApiConfigRequest = None,
+        request: Union[apigateway.UpdateApiConfigRequest, dict] = None,
         *,
         api_config: apigateway.ApiConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single ApiConfig.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.UpdateApiConfigRequest`):
+            request (Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApiConfig
             api_config (:class:`google.cloud.apigateway_v1.types.ApiConfig`):
@@ -1489,17 +1491,17 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_api_config(
         self,
-        request: apigateway.DeleteApiConfigRequest = None,
+        request: Union[apigateway.DeleteApiConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single ApiConfig.
 
         Args:
-            request (:class:`google.cloud.apigateway_v1.types.DeleteApiConfigRequest`):
+            request (Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApiConfig
             name (:class:`str`):
@@ -1588,6 +1590,12 @@ class ApiGatewayServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
