@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.apigateway_v1.services.api_gateway_service import pagers
@@ -424,10 +426,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def list_gateways(
@@ -435,7 +434,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.ListGatewaysRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGatewaysPager:
@@ -515,7 +514,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.GetGatewayRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Gateway:
@@ -592,7 +591,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         parent: str = None,
         gateway: apigateway.Gateway = None,
         gateway_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -694,7 +693,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         *,
         gateway: apigateway.Gateway = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -790,7 +789,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.DeleteGatewayRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -882,7 +881,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.ListApisRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApisPager:
@@ -962,7 +961,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.GetApiRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Api:
@@ -1035,7 +1034,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         parent: str = None,
         api: apigateway.Api = None,
         api_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1135,7 +1134,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         *,
         api: apigateway.Api = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1228,7 +1227,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.DeleteApiRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1320,7 +1319,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.ListApiConfigsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApiConfigsPager:
@@ -1400,7 +1399,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.GetApiConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.ApiConfig:
@@ -1474,7 +1473,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         parent: str = None,
         api_config: apigateway.ApiConfig = None,
         api_config_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1574,7 +1573,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         *,
         api_config: apigateway.ApiConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1668,7 +1667,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         request: Union[apigateway.DeleteApiConfigRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1755,6 +1754,19 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
