@@ -21,7 +21,6 @@ from google.api_core import grpc_helpers_async  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -160,7 +159,7 @@ class ApiGatewayServiceGrpcAsyncIOTransport(ApiGatewayServiceTransport):
         self._grpc_channel = None
         self._ssl_channel_credentials = ssl_channel_credentials
         self._stubs: Dict[str, Callable] = {}
-        self._operations_client = None
+        self._operations_client: Optional[operations_v1.OperationsAsyncClient] = None
 
         if api_mtls_endpoint:
             warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
@@ -656,5 +655,8 @@ class ApiGatewayServiceGrpcAsyncIOTransport(ApiGatewayServiceTransport):
             )
         return self._stubs["delete_api_config"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("ApiGatewayServiceGrpcAsyncIOTransport",)
